# gnuplot 4.2 plot file
set multiplot

# main plot
reset
set encoding iso_8859_1

set rmargin at screen 0.998
set tmargin at screen 0.98
set lmargin at screen 0.1111
set bmargin at screen 0.40

set format x "%.0s%c"
set format y "10^{%T}"

set xlabel "Fourier frequency (Hz)"
set ylabel "relative pointing noise (Hz^{-1/2})"
set key right top
set logscale x
set logscale y
set yrange [:]
set xrange [1:10e3]

set grid
set mxtics 10
set mytics 10

set size 1, 0.8
set samples 500

set style line 30 lt rgb "#d3362b" lw 2
set style line 31 lt rgb "#ffbd23" lw 2
set style line 32 lt rgb "#2a4577" lw 2
set style line 33 lt rgb "#2eaeb3" lw 2
set style line 34 lt rgb "#008a2e" lw 2
set style line 35 lt rgb "dark-magenta" lw 3

nan = sqrt(-1)
req_pnt(f) = (f>=100) ? (f<10e3) ? 2.5e-6 : nan : (f>=10) ? 2.5e-6 * 100**2/f**2 : nan

set xtics 1,10,9e3
set xtics add ("10k      " 10e3)

plot \
  'plot_lsd.dat' u 1:2 title '1x'  w l ls 30,\
  '' u 1:4 title '2x'  w l ls 31,\
  '' u 1:3 title '1y'  w l ls 32,\
  '' u 1:5 title '2y'  w l ls 33,\
  req_pnt(x)*63 title 'laser requirements' w l ls 35


# subplot 1
reset

set rmargin at screen 0.45
set tmargin at screen 0.31
set lmargin at screen 0.1111
set bmargin at screen 0.06

set xlabel "time (s)"
set ylabel "relative pointing"
set grid front
set size 0.6, 0.5
set style fill solid 0.25 border

set style line 30 lt rgb "#d3362b" lw 2
set style line 31 lt rgb "#ffbd23" lw 2
set style line 32 lt rgb "#2a4577" lw 2
set style line 33 lt rgb "#2eaeb3" lw 2


plot [1:60] \
  'plot_timesignal.dat' using ($1/16+1):($2- 0.0252323815858) notitle w l ls 30, \
  '' using ($1/16+1):($4 - 0.635766882325) notitle w l ls 31, \
  '' using ($1/16+1):($3 - -0.181617607238) notitle w l ls 32, \
  '' using ($1/16+1):($5 - 0.151336179053) notitle w l ls 33


# subplot 2

reset

set rmargin at screen 0.75
set tmargin at screen 0.31
set lmargin at screen 0.5
set bmargin at screen 0.06

set ylabel "1X" offset 1
set xlabel "2X" offset 0,1.5
set grid front
set size 0.6, 0.5
set style fill solid 0.25 border

set palette model RGB  
set palette defined ( 0 "white", 1 "yellow", 2 "orange", 3 "red", 4 "#8B0000")
unset colorbox

set size square
set format x ""
set format y ""

set parametric

set xtics ( 3.57143368346e-05)  
set ytics ( -3.67410865518e-05)  

fx(t)=3.57143368346e-05+0.5*0.0434452940174*cos(t) 
fy(t)=-3.67410865518e-05+0.5*0.0388237886744*sin(t)

set xrange [-0.2202495:0.2048464]
set yrange [-0.2147364:0.2103595]
plot\
  'plot_histogramx.dat' using 1:2:3 notitle with image, \
  fx(t), fy(t) notitle w l lt 0



# subplot 3

reset

set rmargin at screen 0.998
set tmargin at screen 0.31
set lmargin at screen 0.776
set bmargin at screen 0.06

set ylabel "1Y" offset 1
set xlabel "2Y" offset 0,1.5
set grid front
set size 0.6, 0.5
set style fill solid 0.25 border

set palette model RGB  
set palette defined ( 0 "white", 1 "yellow", 2 "orange", 3 "red", 4 "#8B0000")
unset colorbox

set size square
set format x ""
set format y ""
set parametric

set xtics ( 0.000213106701447)  
set ytics ( 1.26720212546e-05)  

fx(t)=0.000213106701447+0.5*0.0463165099758*cos(t) 
fy(t)=1.26720212546e-05+0.5*0.0715256405196*sin(t)

set xrange [-0.2961703:0.2885878] 
set yrange [-0.2813346:0.3034235]
plot\
  'plot_histogramy.dat' using 1:2:3 notitle with image, \
  fx(t), fy(t) notitle w l lt 0




unset multiplot
